package gomod

import (
	//	"io"
	"encoding/json"
	"fmt"
	"net/http"
	"path/filepath"
	"payease_declaration/models"
	"payease_declaration/utils"
)

//结算配置提交
func SettlementOrderRequest(w http.ResponseWriter, r *http.Request) {
	//接口地址
	apiurl := "https://apis.5upay.com/declaration/submerchant/settlementProfile/order"
	//pfx私钥
	privatepfxpath, pfxerr := filepath.Abs("src/payease_declaration/package/client.pfx")
	if pfxerr != nil {
		fmt.Println("pfxerr:", pfxerr)
	}
	pfxpwd := "123456"
	//cer公钥
	publiccerpath, cererr := filepath.Abs("src/payease_declaration/package/payease.cer")
	if cererr != nil {
		fmt.Println("cererr:", cererr)
	}
	var aesKeyValue string = utils.GetRandomString(16)
	r.ParseForm()
	var sporder models.SettlementProfile
	sporder.MerchantId = utils.IsNull(r.Form["merchantId"])
	sporder.RequestId = utils.IsNull(r.Form["requestId"])                 //订单号
	sporder.SubMerchantId = utils.IsNull(r.Form["subMerchantId"])         //二级商户编号
	sporder.SettleMode = utils.IsNull(r.Form["settleMode"])               //结算模式
	sporder.CycleType = utils.IsNull(r.Form["cycleType"])                 //周期类型
	sporder.CycleData = utils.IsNull(r.Form["cycleData"])                 //结算日期
	sporder.MinAmount = utils.IsNull(r.Form["minAmount"])                 //起结金额
	sporder.RecName = utils.IsNull(r.Form["recName"])                     //收款方帐户名称
	sporder.RecBankAccountNo = utils.IsNull(r.Form["recBankAccountNo"])   //收款方帐户号
	sporder.RecIdCardNum = utils.IsNull(r.Form["recIdCardNum"])           //收款人身份证号
	sporder.RecBankPhoneNum = utils.IsNull(r.Form["recBankPhoneNum"])     //收款预留手机号
	sporder.RecBankCode = utils.IsNull(r.Form["recBankCode"])             //收款帐户银行编码
	sporder.RecBranchBankName = utils.IsNull(r.Form["recBranchBankName"]) //开户行支付名称
	sporder.RecProvinceCode = utils.IsNull(r.Form["recProvinceCode"])     //收款方省编码
	sporder.RecCityCode = utils.IsNull(r.Form["recCityCode"])             //收款方市编码
	sporder.RecAccountType = utils.IsNull(r.Form["recAccountType"])       //收款人账户类型
	//把订单对象数据转JSON字符串
	orderdata, err := json.Marshal(sporder)
	if err != nil {
		fmt.Printf(err.Error())
		return
	}
	//fmt.Println("orderdata:", string(orderdata))
	sortdata, oerr := utils.GetMapSortJson(string(orderdata))
	if oerr != nil {
		fmt.Println("oerr:", oerr)
	}
	//fmt.Println("sortdata:", sortdata)
	hm := utils.Sha1(sortdata)
	hmac, err := utils.Sign(hm, privatepfxpath, pfxpwd)
	if err != nil {
		fmt.Println("err:", err)
	}
	sporder.Hmac = hmac
	orderjson, err := json.Marshal(sporder)
	if err != nil {
		fmt.Printf(err.Error())
		return
	}
	encryptKey, enerr := utils.PublicEncrypt(aesKeyValue, publiccerpath)
	if enerr != nil {
		fmt.Println("err:", enerr)
	}
	aesdata, aeserro := utils.AesECBEncrypt(string(orderjson), aesKeyValue)
	//fmt.Println("aesdata:", aesdata)
	if aeserro != nil {
		fmt.Println("err:", aeserro)
	}
	response, rperr := utils.Post(apiurl, encryptKey, sporder.MerchantId, sporder.RequestId, aesdata, privatepfxpath, pfxpwd)
	if rperr != nil {
		fmt.Println("rperr:", rperr)
	}
	var spback models.SettlementProfileBack
	json.Unmarshal([]byte(response), &spback)
	rhmac := spback.Hmac
	//fmt.Println("rhmac:", rhmac)
	if rhmac != "" {
		sortdeldata, oerr := utils.GetDelJson(string(response), "hmac")
		if oerr != nil {
			fmt.Println("oerr:", oerr)
		}
		signhm := utils.Sha1(sortdeldata)
		verr := utils.VerifySign(signhm, publiccerpath, rhmac)
		if verr == nil {
			status := spback.Status
			if status == "SUCCESS" {
				fmt.Println("SUCCESS")
				fmt.Println("响应成功!")
				fmt.Println("response:", response)
				fmt.Fprintf(w, "响应成功:"+status)
				fmt.Fprintf(w, "\n"+response)
			} else {
				fmt.Println("响应异常:", status)
				fmt.Println("response:", response)
				fmt.Fprintf(w, "响应异常:"+status)
				fmt.Fprintf(w, "\n"+response)
			}
		} else {
			fmt.Println("verr:", verr)
			fmt.Fprintf(w, "验签异常!")
		}
	} else {
		fmt.Println("response:", response)
		fmt.Fprintf(w, response)
	}
}

//计费配置信息提交
func BillingOrderRequest(w http.ResponseWriter, r *http.Request) {
	//接口地址
	apiurl := "https://apis.5upay.com/declaration/submerchant/billing/order"
	//pfx私钥
	privatepfxpath, pfxerr := filepath.Abs("src/payease_declaration/package/client.pfx")
	if pfxerr != nil {
		fmt.Println("pfxerr:", pfxerr)
	}
	pfxpwd := "123456"
	//cer公钥
	publiccerpath, cererr := filepath.Abs("src/payease_declaration/package/payease.cer")
	if cererr != nil {
		fmt.Println("cererr:", cererr)
	}
	var aesKeyValue string = utils.GetRandomString(16)
	r.ParseForm()
	var border models.Billing
	border.MerchantId = utils.IsNull(r.Form["merchantId"])
	border.RequestId = utils.IsNull(r.Form["requestId"])
	border.SubMerchantId = utils.IsNull(r.Form["subMerchantId"])
	border.BillingMode = utils.IsNull(r.Form["billingMode"])   //计费模式
	border.FeeType = utils.IsNull(r.Form["feeType"])           //收费类型
	border.FeeValue = utils.IsNull(r.Form["feeValue"])         //收费值
	border.MinFeeAmount = utils.IsNull(r.Form["minFeeAmount"]) //最小收费金额
	border.MaxFeeAmount = utils.IsNull(r.Form["maxFeeAmount"]) //最大收费金额

	fmt.Println("border:", border)
	//把订单对象数据转JSON字符串
	orderdata, err := json.Marshal(border)
	if err != nil {
		fmt.Printf(err.Error())
		return
	}
	sortdata, oerr := utils.GetMapSortJson(string(orderdata))
	if oerr != nil {
		fmt.Println("oerr:", oerr)
	}
	hm := utils.Sha1(sortdata)
	hmac, err := utils.Sign(hm, privatepfxpath, pfxpwd)
	if err != nil {
		fmt.Println("err:", err)
	}
	border.Hmac = hmac
	orderjson, err := json.Marshal(border)
	if err != nil {
		fmt.Printf(err.Error())
		return
	}
	encryptKey, enerr := utils.PublicEncrypt(aesKeyValue, publiccerpath)
	if enerr != nil {
		fmt.Println("err:", enerr)
	}
	aesdata, aeserro := utils.AesECBEncrypt(string(orderjson), aesKeyValue)
	//fmt.Println("aesdata:", aesdata)
	if aeserro != nil {
		fmt.Println("err:", aeserro)
	}
	response, rperr := utils.Post(apiurl, encryptKey, border.MerchantId, border.RequestId, aesdata, privatepfxpath, pfxpwd)
	if rperr != nil {
		fmt.Println("rperr:", rperr)
	}
	var bback models.BillingBack
	json.Unmarshal([]byte(response), &bback)
	rhmac := bback.Hmac
	//fmt.Println("rhmac:", rhmac)
	if rhmac != "" {
		sortdeldata, oerr := utils.GetDelJson(string(response), "hmac")
		if oerr != nil {
			fmt.Println("oerr:", oerr)
		}
		signhm := utils.Sha1(sortdeldata)
		verr := utils.VerifySign(signhm, publiccerpath, rhmac)
		if verr == nil {
			status := bback.Status
			if status == "SUCCESS" {
				fmt.Println("SUCCESS")
				fmt.Println("响应成功!")
				fmt.Println("response:", response)
				fmt.Fprintf(w, "响应成功:"+status)
				fmt.Fprintf(w, "\n"+response)
			} else {
				fmt.Println("响应异常:", status)
				fmt.Println("response:", response)
				fmt.Fprintf(w, "响应异常:"+status)
				fmt.Fprintf(w, "\n"+response)
			}
		} else {
			fmt.Println("verr:", verr)
			fmt.Fprintf(w, "验签异常")
			fmt.Fprintf(w, "\n"+response)
		}
	} else {
		fmt.Println("response:", response)
		fmt.Fprintf(w, response)
	}
}

//结算配置信息查询
func SettlementRuleQueryRequest(w http.ResponseWriter, r *http.Request) {
	//接口地址
	apiurl := "https://apis.5upay.com/declaration/submerchant/billingRule/query"
	//pfx私钥
	privatepfxpath, pfxerr := filepath.Abs("src/payease_declaration/package/client.pfx")
	if pfxerr != nil {
		fmt.Println("pfxerr:", pfxerr)
	}
	pfxpwd := "123456"
	//cer公钥
	publiccerpath, cererr := filepath.Abs("src/payease_declaration/package/payease.cer")
	if cererr != nil {
		fmt.Println("cererr:", cererr)
	}
	var aesKeyValue string = utils.GetRandomString(16)
	r.ParseForm()
	var queryorder models.BillingRuleQuery
	queryorder.MerchantId = utils.IsNull(r.Form["merchantId"])
	queryorder.SubMerchantId = utils.IsNull(r.Form["subMerchantId"])
	//把订单对象数据转JSON字符串
	orderdata, err := json.Marshal(queryorder)
	if err != nil {
		fmt.Printf(err.Error())
		return
	}
	sortdata, oerr := utils.GetMapSortJson(string(orderdata))
	//fmt.Println("sortdata:", sortdata)
	if oerr != nil {
		fmt.Println("oerr:", oerr)
	}
	hm := utils.Sha1(sortdata)
	hmac, err := utils.Sign(hm, privatepfxpath, pfxpwd)
	if err != nil {
		fmt.Println("err:", err)
	}
	queryorder.Hmac = hmac
	orderjson, err := json.Marshal(queryorder)
	if err != nil {
		fmt.Printf(err.Error())
		return
	}
	encryptKey, enerr := utils.PublicEncrypt(aesKeyValue, publiccerpath)
	if enerr != nil {
		fmt.Println("err:", enerr)
	}
	aesdata, aeserro := utils.AesECBEncrypt(string(orderjson), aesKeyValue)
	//fmt.Println("aesdata:", aesdata)
	if aeserro != nil {
		fmt.Println("err:", aeserro)
	}
	response, rperr := utils.Post(apiurl, encryptKey, queryorder.MerchantId, "", aesdata, privatepfxpath, pfxpwd)
	if rperr != nil {
		fmt.Println("rperr:", rperr)
	}
	var querybrback models.BillingRuleQueryBack
	json.Unmarshal([]byte(response), &querybrback)
	rhmac := querybrback.Hmac
	//fmt.Println("queryorder:", querybrback)
	if rhmac != "" {
		sortdeldata, oerr := utils.GetDelJson(string(response), "hmac")
		if oerr != nil {
			fmt.Println("oerr:", oerr)
		}
		signhm := utils.Sha1(sortdeldata)
		verr := utils.VerifySign(signhm, publiccerpath, rhmac)
		if verr == nil {
			status := querybrback.Status
			if status == "SUCCESS" {
				fmt.Println("SUCCESS")
				fmt.Println("响应成功!")
				fmt.Println("response:", response)
				fmt.Fprintf(w, "响应成功:"+status)
				fmt.Fprintf(w, "\n"+response)
			} else {
				fmt.Println("响应异常:", status)
				fmt.Println("response:", response)
				fmt.Fprintf(w, "响应异常:"+status)
				fmt.Fprintf(w, "\n"+response)
			}
		} else {
			fmt.Println("verr:", verr)
		}
	} else {
		fmt.Println("response:", response)
		fmt.Fprintf(w, "response:"+response)
	}
}
